Badges
======
PyPI
~~~~

.. image:: https://img.shields.io/pypi/v/cool-django-auth-ldap?style=flat-square
   :target: https://pypi.org/project/cool-django-auth-ldap/
.. image:: https://img.shields.io/pypi/pyversions/cool-django-auth-ldap?style=flat-square
   :target: https://pypi.org/project/cool-django-auth-ldap/
.. image:: https://img.shields.io/pypi/djversions/cool-django-auth-ldap?style=flat-square
   :target: https://pypi.org/project/cool-django-auth-ldap/

Master
~~~~~~

.. image:: https://img.shields.io/travis/nonameitem/cool-django-auth-ldap/master?style=flat-square
   :target: https://travis-ci.org/NoNameItem/cool-django-auth-ldap
.. image:: https://img.shields.io/coveralls/github/NoNameItem/cool-django-auth-ldap/master?style=flat-square
   :target: https://coveralls.io/github/NoNameItem/cool-django-auth-ldap
.. image:: https://img.shields.io/readthedocs/cool-django-auth-ldap/latest?style=flat-square
   :target: https://cool-django-auth-ldap.readthedocs.io/en/latest/
.. image:: https://img.shields.io/codeclimate/maintainability/NoNameItem/cool-django-auth-ldap?style=flat-square
   :target: https://codeclimate.com/github/NoNameItem/cool-django-auth-ldap
   
Develop
~~~~~~~

.. image:: https://img.shields.io/travis/nonameitem/cool-django-auth-ldap/develop?style=flat-square
   :target: https://travis-ci.org/NoNameItem/cool-django-auth-ldap
.. image:: https://img.shields.io/coveralls/github/NoNameItem/cool-django-auth-ldap/develop?style=flat-square
   :target: https://coveralls.io/github/NoNameItem/cool-django-auth-ldap
.. image:: https://img.shields.io/readthedocs/cool-django-auth-ldap/develop?style=flat-square
   :target: https://cool-django-auth-ldap.readthedocs.io/en/develop/
   
Install
=======
::

  pip install cool-django-auth-ldap

Readme
======

This is fork of django-auth-ldap 2.0.0. I tried to save all original features while adding few new ones. In 95% original documentation is still applies,
just replace package name `django_auth_ldap` to `cool_django_auth_ldap`. All changes described in this readme.

Original documentation: https://django-auth-ldap.readthedocs.io/en/2.0.0/
